summaryrefslogtreecommitdiffstats
path: root/bksys/kde.py
diff options
context:
space:
mode:
Diffstat (limited to 'bksys/kde.py')
-rw-r--r--bksys/kde.py49
1 files changed, 26 insertions, 23 deletions
diff --git a/bksys/kde.py b/bksys/kde.py
index 1055a7e..e38f4e3 100644
--- a/bksys/kde.py
+++ b/bksys/kde.py
@@ -32,7 +32,7 @@ def KDEuse(lenv, flags):
if 'thread' in _flags:
## Uncomment the following if you need threading support
lenv.KDEaddflags_cxx( ['-DQT_THREAD_SUPPORT', '-D_REENTRANT'] )
- if 'fastmoc' in _flags:
+ if 'fasmoc' in _flags:
lenv['BKSYS_FASTMOC']=1
if 'dump' in _flags:
lenv['DUMPCONFIG']=1
@@ -109,40 +109,40 @@ def detect_kde(env):
p('GREEN',kde_version)
## Detect the qt library
- print "Checking for the qt library : ",
+ print "Checking for the tqt library : ",
if not qtdir: qtdir = os.getenv("QTDIR")
if qtdir:
- p('GREEN',"qt is in "+qtdir)
+ p('GREEN',"tqt is in "+qtdir)
else:
try:
tmplibdir = os.popen(kde_config+' --expandvars --install lib').read().strip()
libkdeuiSO = env.join(tmplibdir, getSOfromLA(env.join(tmplibdir,'/libkdeui.la')) )
- m = re.search('(.*)/lib/libqt.*', os.popen('ldd ' + libkdeuiSO + ' | grep libqt').read().strip().split()[2])
+ m = re.search('(.*)/lib/libtqt.*', os.popen('ldd ' + libkdeuiSO + ' | grep libtqt').read().strip().split()[2])
except: m=None
if m:
qtdir = m.group(1)
- p('YELLOW',"qt was found as "+m.group(1))
+ p('YELLOW',"tqt was found as "+m.group(1))
else:
- p('RED','qt was not found')
- p('RED','Please set QTDIR first (/usr/lib/qt3?) or try scons -h for more options')
+ p('RED','tqt was not found')
+ p('RED','Please set QTDIR first (/usr/lib/tqt?) or try scons -h for more options')
env.Exit(1)
env['QTDIR'] = qtdir.strip()
## Find the necessary programs uic and moc
print "Checking for uic : ",
- uic = qtdir + "/bin/uic"
+ uic = qtdir + "/bin/uic-tqt"
if os.path.isfile(uic):
- p('GREEN',"uic was found as "+uic)
+ p('GREEN',"uic-tqt was found as "+uic)
else:
- uic = os.popen("which uic 2>/dev/null").read().strip()
+ uic = os.popen("which uic-tqt 2>/dev/null").read().strip()
if len(uic):
- p('YELLOW',"uic was found as "+uic)
+ p('YELLOW',"uic-tqt was found as "+uic)
else:
- uic = os.popen("which uic 2>/dev/null").read().strip()
+ uic = os.popen("which uic-tqt 2>/dev/null").read().strip()
if len(uic):
- p('YELLOW',"uic was found as "+uic)
+ p('YELLOW',"uic-tqt was found as "+uic)
else:
- p('RED',"uic was not found - set QTDIR put it in your PATH ?")
+ p('RED',"uic-tqt was not found - set QTDIR put it in your PATH ?")
env.Exit(1)
env['QT_UIC'] = uic
@@ -162,22 +162,25 @@ def detect_kde(env):
env.Exit(1)
env['QT_MOC'] = moc
- ## check for the qt and kde includes
- print "Checking for the qt includes : ",
- if qtincludes and os.path.isfile(qtincludes + "/qlayout.h"):
+ ## check for the tqt and kde includes
+ print "Checking for the tqt includes : ",
+ if qtincludes and os.path.isfile(qtincludes + "/tqt.h"):
# The user told where to look for and it looks valid
p('GREEN',"ok "+qtincludes)
else:
- if os.path.isfile(qtdir + "/include/qlayout.h"):
+ if os.path.isfile(qtdir + "/include/tqt.h"):
# Automatic detection
p('GREEN',"ok "+qtdir+"/include/")
qtincludes = qtdir + "/include/"
- elif os.path.isfile("/usr/include/qt3/qlayout.h"):
+ elif os.path.isfile("/usr/include/tqt.h"):
+ p('YELLOW','the qt headers were found in /usr/include/')
+ qtincludes = "/usr/include"
+ elif os.path.isfile("/usr/include/tqt/tqt.h"):
# Debian probably
- p('YELLOW','the qt headers were found in /usr/include/qt3/')
- qtincludes = "/usr/include/qt3"
+ p('YELLOW','the qt headers were found in /usr/include/tqt/')
+ qtincludes = "/usr/include/tqt"
else:
- p('RED',"the qt headers were not found")
+ p('RED',"the tqt headers were not found")
env.Exit(1)
print "Checking for the kde includes : ",
@@ -336,7 +339,7 @@ def generate(env):
opts.Save(cachefile, env)
## set default variables, one can override them in sconscript files
- env.Append(CXXFLAGS = ['-I'+env['KDEINCLUDEPATH'], '-I'+env['QTINCLUDEPATH'] ],
+ env.Append(CXXFLAGS = ['-I'+env['KDEINCLUDEPATH'], '-I'+env['QTINCLUDEPATH'], '-I/usr/include/qt4', '-includetqt.h' ],
LIBPATH = [env['KDELIBPATH'], env['QTLIBPATH'] ])
env['QT_AUTOSCAN'] = 1